API reference
=============

.. autofunction:: turbodbc.connect

.. autofunction:: turbodbc.make_options

.. autoclass:: turbodbc.connection.Connection
    :members:

.. autoclass:: turbodbc.cursor.Cursor
    :members:

.. autoclass:: turbodbc.exceptions.Error

.. autoclass:: turbodbc.exceptions.InterfaceError

.. autoclass:: turbodbc.exceptions.DatabaseError

.. autoclass:: turbodbc.exceptions.ParameterError
